@@ -1,6 +1,7 @@
 import yaml
 
 from qhub.initialize import render_config
+from qhub.schema import ProviderEnum
 
 
 def create_init_subcommand(subparser):
@@ -9,11 +10,15 @@ def create_init_subcommand(subparser):
         "platform",
         help="Cloud to deploy qhub on",
         type=str,
-        choices=["do", "gcp", "aws"],
+        choices=[_.value for _ in ProviderEnum],
     )
-    subparser.add_argument("--project", help="Namespace to assign to qhub resources")
+    subparser.add_argument("--project", help="Name to assign to qhub resources")
     subparser.add_argument(
-        "--domain", help="Domain for jupyterhub clister to be deployed under"
+        "--namespace", default="dev", help="Namespace to assign to qhub resources"
+    )
+    subparser.add_argument(
+        "--domain",
+        help="Domain for jupyterhub cluster to be deployed under",
     )
     subparser.add_argument(
         "--ci-provider",
@@ -22,10 +27,10 @@ def create_init_subcommand(subparser):
         help="continuous integration to use for infrastructure as code",
     )
     subparser.add_argument(
-        "--oauth-provider",
-        choices=["github", "auth0"],
+        "--auth-provider",
+        choices=["github", "auth0", "password"],
         default="github",
-        help="oauth provider to use for authentication",
+        help="auth provider to use for authentication",
     )
     subparser.add_argument("--repository", help="Repository to initialize qhub")
     subparser.add_argument(
@@ -34,9 +39,15 @@ def create_init_subcommand(subparser):
         help="Attempt to automatically provision repository. For github it requires environment variables GITHUB_USERNAME, GITHUB_TOKEN",
     )
     subparser.add_argument(
-        "--oauth-auto-provision",
+        "--auth-auto-provision",
         action="store_true",
-        help="Attempt to automatically provision oauth. For Auth0 it requires environment variables AUTH0_DOMAIN, AUTH0_CLIENTID, AUTH0_CLIENT_SECRET",
+        help="Attempt to automatically provision authentication. For Auth0 it requires environment variables AUTH0_DOMAIN, AUTH0_CLIENTID, AUTH0_CLIENT_SECRET",
+    )
+    subparser.add_argument(
+        "--terraform-state",
+        choices=["remote", "local", "existing"],
+        default="remote",
+        help="Terraform state to be provisioned and stored remotely, locally on the filesystem, or using existing terraform state backend",
     )
     subparser.add_argument(
         "--kubernetes-version",
@@ -54,13 +65,15 @@ def create_init_subcommand(subparser):
 def handle_init(args):
     config = render_config(
         project_name=args.project,
+        namespace=args.namespace,
         qhub_domain=args.domain,
         cloud_provider=args.platform,
         ci_provider=args.ci_provider,
         repository=args.repository,
-        oauth_provider=args.oauth_provider,
         repository_auto_provision=args.repository_auto_provision,
-        oauth_auto_provision=args.oauth_auto_provision,
+        auth_provider=args.auth_provider,
+        auth_auto_provision=args.auth_auto_provision,
+        terraform_state=args.terraform_state,
         kubernetes_version=args.kubernetes_version,
         disable_prompt=args.disable_prompt,
     )
